"""Convenience wrapper for the OpenSCAPGeneric step implementer so that users
can specify 'OpenSCAP' for the 'container-image-static-compliance-scan'.

Step Configuration
------------------

Step configuration expected as input to this step.
Could come from either configuration file or
from runtime configuration.

| Configuration Key              | Required? | Default | Description
|--------------------------------|-----------|---------|-----------
| `oscap-input-definitions-uri`  | Yes       |         | URI to the OpenSCAP definitions file
|                                |           |         | to do the evaluation with.
|                                |           |         | Must use protocol file://|http://|https://.
|                                |           |         | Must have file extension .xml|.bz2.
| `oscap-profile`                | Yes       |         | OpenSCAP profile to evaluate.
| `oscap-tailoring-uri`          | No        |         | URI to OpenSCAP tailoring file
|                                |           |         | to do the evaluation with.
|                                |           |         | Must use protocol file://|http://|https://.
|                                |           |         | Must have file extension .xml|.bz2.
| `oscap-fetch-remote-resources` | No        | True    | For Source DataStream and XCCDF files
|                                |           |         | that have remote references fetch them if
|                                |           |         | True, else don't.
|                                |           |         |
|                                |           |         | WARNING: evaluations will not be complete
|                                |           |         | if input defintions require remote
|                                |           |         | resources and this is not True.
|                                |           |         | For disconnected environments the remote
|                                |           |         | references should be brought to an internal
|                                |           |         | mirror.

Expected Previous Step Results
------------------------------

Results expected from previous steps that this step requires.

| Step Name                | Result Key       | Description
|--------------------------|------------------|--------------
| `create-container-image` | `image-tar-file` | Image to scan

Results
-------

Results output by this step.

| Result Key      | Description
|-----------------|------------
| `html-report`   | HTML report generated by oscap eval
| `xml-report`    | XML report generated by oscap eval
| `stdout-report` | stdout report generated by oscap eval
"""

from tssc.step_implementers.shared.openscap_generic import OpenSCAPGeneric

REQUIRED_CONFIG_KEYS = [
    'oscap-profile'
]

class OpenSCAP(OpenSCAPGeneric):
    """Convenience wrapper for the OpenSCAPGeneric step implementer so that users
    can specify 'OpenSCAP' for the 'container-image-static-compliance-scan'.

    Since compliance scans with oscap require a profile, also extends to sets the 'oscap-profile'
    as a required configuration key.
    """

    @staticmethod
    def required_runtime_step_config_keys():
        """Getter for step configuration keys that are required before running the step.

        See Also
        --------
        _validate_runtime_step_config

        Returns
        -------
        array_list
            Array of configuration keys that are required before running the step.
        """
        return REQUIRED_CONFIG_KEYS + OpenSCAPGeneric.required_runtime_step_config_keys()
