"""Convenience wrapper for the OpenSCAPGeneric step implementer so that users
can specify 'OpenSCAP' for the 'container-image-static-vulnerability-scan'.

Step Configuration
------------------

Step configuration expected as input to this step.
Could come from either configuration file or
from runtime configuration.

| Configuration Key              | Required? | Default | Description
|--------------------------------|-----------|---------|-----------
| `oscap-input-definitions-uri`  | Yes       |         | URI to the OpenSCAP definitions file
|                                |           |         | to do the evaluation with.
|                                |           |         | Must use protocol file://|http://|https://.
|                                |           |         | Must have file extension .xml|.bz2.
| `oscap-profile`                | No        |         | OpenSCAP profile to evaluate.
| `oscap-tailoring-uri`          | No        |         | URI to OpenSCAP tailoring file
|                                |           |         | to do the evaluation with.
|                                |           |         | Must use protocol file://|http://|https://.
|                                |           |         | Must have file extension .xml|.bz2.
| `oscap-fetch-remote-resources` | No        | True    | For Source DataStream and XCCDF files
|                                |           |         | that have remote references fetch them if
|                                |           |         | True, else don't.
|                                |           |         |
|                                |           |         | WARNING: evaluations will not be complete
|                                |           |         | if input defintions require remote
|                                |           |         | resources and this is not True.
|                                |           |         | For disconnected environments the remote
|                                |           |         | references should be brought to an internal
|                                |           |         | mirror.

Expected Previous Step Results
------------------------------

Results expected from previous steps that this step requires.

| Step Name                | Result Key       | Description
|--------------------------|------------------|--------------
| `create-container-image` | `image-tar-file` | Image to scan

Results
-------

Results output by this step.

| Result Key      | Description
|-----------------|------------
| `html-report`   | HTML report generated by oscap eval
| `xml-report`    | XML report generated by oscap eval
| `stdout-report` | stdout report generated by oscap eval
"""

from tssc.step_implementers.shared.openscap_generic import OpenSCAPGeneric

class OpenSCAP(OpenSCAPGeneric):
    """Convenience wrapper for the OpenSCAPGeneric step implementer so that users
    can specify 'OpenSCAP' for the 'container-image-static-vulnerability-scan'.
    """
